==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeComputePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The compute resource properties for managed integration runtime.
 * @property copyComputeScaleProperties CopyComputeScale properties for managed integration runtime.
 * @property dataFlowProperties Data flow properties for managed integration runtime.
 * @property location The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
 * @property maxParallelExecutionsPerNode Maximum parallel executions count per node for managed integration runtime.
 * @property nodeSize The node size requirement to managed integration runtime.
 * @property numberOfNodes The required number of nodes for managed integration runtime.
 * @property pipelineExternalComputeScaleProperties PipelineExternalComputeScale properties for managed integration runtime.
 * @property vNetProperties VNet properties for managed integration runtime.
 */
public data class IntegrationRuntimeComputePropertiesArgs(
    public val copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null,
    public val dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maxParallelExecutionsPerNode: Output<Int>? = null,
    public val nodeSize: Output<String>? = null,
    public val numberOfNodes: Output<Int>? = null,
    public val pipelineExternalComputeScaleProperties:
    Output<PipelineExternalComputeScalePropertiesArgs>? = null,
    public val vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder()
            .copyComputeScaleProperties(
                copyComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataFlowProperties(
                dataFlowProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .maxParallelExecutionsPerNode(maxParallelExecutionsPerNode?.applyValue({ args0 -> args0 }))
            .nodeSize(nodeSize?.applyValue({ args0 -> args0 }))
            .numberOfNodes(numberOfNodes?.applyValue({ args0 -> args0 }))
            .pipelineExternalComputeScaleProperties(
                pipelineExternalComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .vNetProperties(
                vNetProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeComputePropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeComputePropertiesArgsBuilder internal constructor() {
    private var copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null

    private var dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maxParallelExecutionsPerNode: Output<Int>? = null

    private var nodeSize: Output<String>? = null

    private var numberOfNodes: Output<Int>? = null

    private var pipelineExternalComputeScaleProperties:
        Output<PipelineExternalComputeScalePropertiesArgs>? = null

    private var vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("lsapwyutwcundodm")
    public suspend fun copyComputeScaleProperties(`value`: Output<CopyComputeScalePropertiesArgs>) {
        this.copyComputeScaleProperties = value
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("qeefptyyouikaoxv")
    public suspend fun dataFlowProperties(`value`: Output<IntegrationRuntimeDataFlowPropertiesArgs>) {
        this.dataFlowProperties = value
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("pscoxlxvcdlrgvie")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("usegsucfdmxinprs")
    public suspend fun maxParallelExecutionsPerNode(`value`: Output<Int>) {
        this.maxParallelExecutionsPerNode = value
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("kvvwucmxmrqmerhd")
    public suspend fun nodeSize(`value`: Output<String>) {
        this.nodeSize = value
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("xqmhkmapvdojcujl")
    public suspend fun numberOfNodes(`value`: Output<Int>) {
        this.numberOfNodes = value
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("hjnlmtnipwsqlbif")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: Output<PipelineExternalComputeScalePropertiesArgs>) {
        this.pipelineExternalComputeScaleProperties = value
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("stfnsllmexpotvox")
    public suspend fun vNetProperties(`value`: Output<IntegrationRuntimeVNetPropertiesArgs>) {
        this.vNetProperties = value
    }

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("vkwejhgvtkpqhkiv")
    public suspend fun copyComputeScaleProperties(`value`: CopyComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param argument CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("ldgyfekvwnvhghsj")
    public suspend
    fun copyComputeScaleProperties(argument: suspend CopyComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CopyComputeScalePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("lcdwlowqcefjmlxx")
    public suspend fun dataFlowProperties(`value`: IntegrationRuntimeDataFlowPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFlowProperties = mapped
    }

    /**
     * @param argument Data flow properties for managed integration runtime.
     */
    @JvmName("nevorrakkmbqsxqi")
    public suspend
    fun dataFlowProperties(argument: suspend IntegrationRuntimeDataFlowPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataFlowPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataFlowProperties = mapped
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("mpwecfpthmjupxyj")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("jblnjqlpocrbapfj")
    public suspend fun maxParallelExecutionsPerNode(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxParallelExecutionsPerNode = mapped
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("ivrtcolgoarukwqp")
    public suspend fun nodeSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeSize = mapped
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("efnoyjplvvenauiv")
    public suspend fun numberOfNodes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.numberOfNodes = mapped
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("ewrkuqdsgvoyrgnf")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: PipelineExternalComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param argument PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("apuasolynnlkechg")
    public suspend
    fun pipelineExternalComputeScaleProperties(argument: suspend PipelineExternalComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineExternalComputeScalePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("dfwqsxqvgjegmdmo")
    public suspend fun vNetProperties(`value`: IntegrationRuntimeVNetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vNetProperties = mapped
    }

    /**
     * @param argument VNet properties for managed integration runtime.
     */
    @JvmName("qpoqmslvekruwoth")
    public suspend
    fun vNetProperties(argument: suspend IntegrationRuntimeVNetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeVNetPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.vNetProperties = mapped
    }

    internal fun build(): IntegrationRuntimeComputePropertiesArgs =
        IntegrationRuntimeComputePropertiesArgs(
            copyComputeScaleProperties = copyComputeScaleProperties,
            dataFlowProperties = dataFlowProperties,
            location = location,
            maxParallelExecutionsPerNode = maxParallelExecutionsPerNode,
            nodeSize = nodeSize,
            numberOfNodes = numberOfNodes,
            pipelineExternalComputeScaleProperties = pipelineExternalComputeScaleProperties,
            vNetProperties = vNetProperties,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeComputePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The compute resource properties for managed integration runtime.
 * @property copyComputeScaleProperties CopyComputeScale properties for managed integration runtime.
 * @property dataFlowProperties Data flow properties for managed integration runtime.
 * @property location The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
 * @property maxParallelExecutionsPerNode Maximum parallel executions count per node for managed integration runtime.
 * @property nodeSize The node size requirement to managed integration runtime.
 * @property numberOfNodes The required number of nodes for managed integration runtime.
 * @property pipelineExternalComputeScaleProperties PipelineExternalComputeScale properties for managed integration runtime.
 * @property vNetProperties VNet properties for managed integration runtime.
 */
public data class IntegrationRuntimeComputePropertiesArgs(
    public val copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null,
    public val dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maxParallelExecutionsPerNode: Output<Int>? = null,
    public val nodeSize: Output<String>? = null,
    public val numberOfNodes: Output<Int>? = null,
    public val pipelineExternalComputeScaleProperties:
    Output<PipelineExternalComputeScalePropertiesArgs>? = null,
    public val vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder()
            .copyComputeScaleProperties(
                copyComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataFlowProperties(
                dataFlowProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .maxParallelExecutionsPerNode(maxParallelExecutionsPerNode?.applyValue({ args0 -> args0 }))
            .nodeSize(nodeSize?.applyValue({ args0 -> args0 }))
            .numberOfNodes(numberOfNodes?.applyValue({ args0 -> args0 }))
            .pipelineExternalComputeScaleProperties(
                pipelineExternalComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .vNetProperties(
                vNetProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeComputePropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeComputePropertiesArgsBuilder internal constructor() {
    private var copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null

    private var dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maxParallelExecutionsPerNode: Output<Int>? = null

    private var nodeSize: Output<String>? = null

    private var numberOfNodes: Output<Int>? = null

    private var pipelineExternalComputeScaleProperties:
        Output<PipelineExternalComputeScalePropertiesArgs>? = null

    private var vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("wfmbbaujqgrimdia")
    public suspend fun copyComputeScaleProperties(`value`: Output<CopyComputeScalePropertiesArgs>) {
        this.copyComputeScaleProperties = value
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("hqouedutnniosvms")
    public suspend fun dataFlowProperties(`value`: Output<IntegrationRuntimeDataFlowPropertiesArgs>) {
        this.dataFlowProperties = value
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("hpfdkkpkpmgxmfqo")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("ouhfynbnoauaqufd")
    public suspend fun maxParallelExecutionsPerNode(`value`: Output<Int>) {
        this.maxParallelExecutionsPerNode = value
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("hxacvixryytlavjg")
    public suspend fun nodeSize(`value`: Output<String>) {
        this.nodeSize = value
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("yjpsevwobgviuldk")
    public suspend fun numberOfNodes(`value`: Output<Int>) {
        this.numberOfNodes = value
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("vahmecrprotilflf")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: Output<PipelineExternalComputeScalePropertiesArgs>) {
        this.pipelineExternalComputeScaleProperties = value
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("fgedbloummusovlf")
    public suspend fun vNetProperties(`value`: Output<IntegrationRuntimeVNetPropertiesArgs>) {
        this.vNetProperties = value
    }

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("ovqwlcovhctmcgdi")
    public suspend fun copyComputeScaleProperties(`value`: CopyComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param argument CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("qbhgdnhcjqkwgjfg")
    public suspend
    fun copyComputeScaleProperties(argument: suspend CopyComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CopyComputeScalePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("ksxorhhrflcikhgt")
    public suspend fun dataFlowProperties(`value`: IntegrationRuntimeDataFlowPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFlowProperties = mapped
    }

    /**
     * @param argument Data flow properties for managed integration runtime.
     */
    @JvmName("mwtkiddjwlpiqynm")
    public suspend
    fun dataFlowProperties(argument: suspend IntegrationRuntimeDataFlowPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataFlowPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataFlowProperties = mapped
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("ljpjghhojgnobxfu")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("ngyunrutgtepvbla")
    public suspend fun maxParallelExecutionsPerNode(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxParallelExecutionsPerNode = mapped
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("krnusnhjqmyqkfpm")
    public suspend fun nodeSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeSize = mapped
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("plfmtulhjnyfrqju")
    public suspend fun numberOfNodes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.numberOfNodes = mapped
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("xeuhapqlnfdpovkj")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: PipelineExternalComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param argument PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("pwinsfefhtqbwssl")
    public suspend
    fun pipelineExternalComputeScaleProperties(argument: suspend PipelineExternalComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineExternalComputeScalePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("ipygllbiafbqkjxt")
    public suspend fun vNetProperties(`value`: IntegrationRuntimeVNetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vNetProperties = mapped
    }

    /**
     * @param argument VNet properties for managed integration runtime.
     */
    @JvmName("qyusrsvlwduegwyc")
    public suspend
    fun vNetProperties(argument: suspend IntegrationRuntimeVNetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeVNetPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.vNetProperties = mapped
    }

    internal fun build(): IntegrationRuntimeComputePropertiesArgs =
        IntegrationRuntimeComputePropertiesArgs(
            copyComputeScaleProperties = copyComputeScaleProperties,
            dataFlowProperties = dataFlowProperties,
            location = location,
            maxParallelExecutionsPerNode = maxParallelExecutionsPerNode,
            nodeSize = nodeSize,
            numberOfNodes = numberOfNodes,
            pipelineExternalComputeScaleProperties = pipelineExternalComputeScaleProperties,
            vNetProperties = vNetProperties,
        )
}
